@@ -25,7 +25,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 # Preloaded methods go here.
@@ -158,49 +158,34 @@ __END__
 
 =head1 NAME
 
-Log::Cabin::Foundation - Perl extension for blah blah blah
+Log::Cabin::Foundation - Foundation class for Log::Cabin
 
 =head1 SYNOPSIS
 
   use Log::Cabin::Foundation;
-  blah blah blah
 
 =head1 DESCRIPTION
 
-Stub documentation for Log::Cabin::Foundation, created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
+See perldoc for Log::Cabin
 
 =head2 EXPORT
 
 None by default.
 
-
-
 =head1 SEE ALSO
 
-Mention other useful documentation such as the documentation of
-related modules or operating system documentation (such as man pages
-in UNIX), or any relevant external documentation such as RFCs or
-standards.
-
-If you have a mailing list set up for your module, mention it here.
-
-If you have a web site set up for your module, mention it here.
+See perldoc for Log::Cabin
 
 =head1 AUTHOR
 
-Samuel Angiuoli, E<lt>angiuoli@tigr.orgE<gt>
+Joshua Orvis, E<lt>jorvis@tigr.orgE<gt> and Sam Angiuoli, E<lt>angiuoli@tigr.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 by Samuel Angiuoli
+This module is available under the Artistic License
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.5 or,
-at your option, any later version of Perl 5 you may have available.
+http://www.opensource.org/licenses/artistic-license.php
 
+Copyright (C) 2006-2007 by Joshua Orvis and Sam Angiuoli
 
 =cut
